@@ -28,7 +28,9 @@
 #include <libspi/accessible.h>
 #include <libspi/action.h>
 #include <libspi/application.h>
+#include <libspi/collection.h>
 #include <libspi/component.h>
+#include <libspi/document.h>
 #include <libspi/editabletext.h>
 #include <libspi/hyperlink.h>
 #include <libspi/hypertext.h>
@@ -44,5 +46,6 @@
 #include <libspi/devicelistener.h>
 #include <libspi/keymasks.h>
 #include <libspi/remoteobject.h>
+#include <libspi/streamablecontent.h>
 
 #endif /* LIBSPI_H_ */
